<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ImportFile</name>
    <message>
        <location filename="../ImportFile.js" line="+68"/>
        <source>Error while importing file %1</source>
        <translation>Błąd podczas importowania pliku %1</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>No import filters have been found. Aborting...</source>
        <translation>Nie odnaleziono filtrów importowania. Anulowanie...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>All Files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Import Drawing</source>
        <translation>Importowanie rysunku</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../ImportFileInit.js" line="+2"/>
        <source>&amp;Import</source>
        <translation>&amp;Importuj</translation>
    </message>
</context>
</TS>
